        function getT(rr,cc){
       if(rr==6 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260614 a 12</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==6 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260614 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>37</strong> miembros: 28 <strong>control</strong><br>0,1,2,7,8,13,14,15,17,20,22,23,24,26,28,29,32,33,34,35,37,38,43,44,46,47,48,50';}
       if(rr==6 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260614 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>42</strong> miembros: 23 <br>3,4,5,6,9,10,11,12,16,18,19,21,25,27,30,31,36,39,40,41,42,45,49';}
       if(rr==29 && cc==0){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260614 a 12</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==29 && cc==1){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260614 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>37</strong> miembros: 28 <strong>control</strong><br>0,1,2,7,8,13,14,15,17,20,22,23,24,26,28,29,32,33,34,35,37,38,43,44,46,47,48,50';}
       if(rr==29 && cc==2){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260614 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>42</strong> miembros: 23 <br>3,4,5,6,9,10,11,12,16,18,19,21,25,27,30,31,36,39,40,41,42,45,49';}
       if(rr==30 && cc==0){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260614 a 12</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==30 && cc==1){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260614 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>37</strong> miembros: 28 <strong>control</strong><br>0,1,2,7,8,13,14,15,17,20,22,23,24,26,28,29,32,33,34,35,37,38,43,44,46,47,48,50';}
       if(rr==30 && cc==2){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260614 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>42</strong> miembros: 23 <br>3,4,5,6,9,10,11,12,16,18,19,21,25,27,30,31,36,39,40,41,42,45,49';}
       if(rr==31 && cc==0){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260614 a 12</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==31 && cc==1){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260614 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>37</strong> miembros: 28 <strong>control</strong><br>0,1,2,7,8,13,14,15,17,20,22,23,24,26,28,29,32,33,34,35,37,38,43,44,46,47,48,50';}
       if(rr==31 && cc==2){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260614 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>42</strong> miembros: 23 <br>3,4,5,6,9,10,11,12,16,18,19,21,25,27,30,31,36,39,40,41,42,45,49';}
       if(rr==32 && cc==0){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260614 a 12</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==32 && cc==1){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260614 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>37</strong> miembros: 28 <strong>control</strong><br>0,1,2,7,8,13,14,15,17,20,22,23,24,26,28,29,32,33,34,35,37,38,43,44,46,47,48,50';}
       if(rr==32 && cc==2){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260614 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>42</strong> miembros: 23 <br>3,4,5,6,9,10,11,12,16,18,19,21,25,27,30,31,36,39,40,41,42,45,49';}
       if(rr==33 && cc==0){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260614 a 12</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==33 && cc==1){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260614 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>37</strong> miembros: 28 <strong>control</strong><br>0,1,2,7,8,13,14,15,17,20,22,23,24,26,28,29,32,33,34,35,37,38,43,44,46,47,48,50';}
       if(rr==33 && cc==2){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260614 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>42</strong> miembros: 23 <br>3,4,5,6,9,10,11,12,16,18,19,21,25,27,30,31,36,39,40,41,42,45,49';}
}
